==> ldap-account-manager_8.0.1.orig.tar.bz2: ldap-account-manager-8.0.1/templates/lib/extra/ckeditor/plugins/link/lang/si.js <==
﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'si', {
	acccessKey: 'ප්‍රවේශ  යතුර',
	advanced: 'දීය',
	advisoryContentType: 'උපදේශාත්මක අන්තර්ගත ආකාරය',
	advisoryTitle: 'උපදේශාත්මක නාමය',
	anchor: {
		toolbar: 'ආධාරය',
		menu: 'ආධාරය වෙනස් කිරීම',
		title: 'ආධාරක ',
		name: 'ආධාරකයේ නාමය',
		errorName: 'කරුණාකර ආධාරකයේ නාමය ඇතුල් කරන්න',
		remove: 'ආධාරකය ඉවත් කිරීම'
	},
	anchorId: 'By Element Id', // MISSING
	anchorName: 'By Anchor Name', // MISSING
	charset: 'Linked Resource Charset', // MISSING
	cssClasses: 'විලාසපත්‍ර පන්තිය',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'E-Mail Address', // MISSING
	emailBody: 'Message Body', // MISSING
	emailSubject: 'Message Subject', // MISSING
	id: 'අංකය',
	info: 'Link Info', // MISSING
	langCode: 'භාෂා කේතය',
	langDir: 'භාෂා දිශාව',
	langDirLTR: 'වමේසිට දකුණුට',
	langDirRTL: 'දකුණේ සිට වමට',
	menu: 'Edit Link', // MISSING
	name: 'නම',
	noAnchors: '(No anchors available in the document)', // MISSING
	noEmail: 'Please type the e-mail address', // MISSING
	noUrl: 'Please type the link URL', // MISSING
	noTel: 'Please type the phone number', // MISSING
	other: '<other>', // MISSING
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Dependent (Netscape)', // MISSING
	popupFeatures: 'Popup Window Features', // MISSING
	popupFullScreen: 'Full Screen (IE)', // MISSING
	popupLeft: 'Left Position', // MISSING
	popupLocationBar: 'Location Bar', // MISSING
	popupMenuBar: 'Menu Bar', // MISSING
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'Scroll Bars', // MISSING
	popupStatusBar: 'Status Bar', // MISSING
	popupToolbar: 'Toolbar', // MISSING
	popupTop: 'Top Position', // MISSING
	rel: 'Relationship', // MISSING
	selectAnchor: 'Select an Anchor', // MISSING
	styles: 'විලාසය',
	tabIndex: 'Tab Index', // MISSING
	target: 'අරමුණ',
	targetFrame: '<frame>', // MISSING
	targetFrameName: 'Target Frame Name', // MISSING
	targetPopup: '<popup window>', // MISSING
	targetPopupName: 'Popup Window Name', // MISSING
	title: 'සබැඳිය',
	toAnchor: 'Link to anchor in the text', // MISSING
	toEmail: 'E-mail', // MISSING
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'සබැඳිය',
	type: 'Link Type', // MISSING
	unlink: 'Unlink', // MISSING
	upload: 'උඩුගතකිරීම'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/link/lang/si.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'link', 'si', {
	acccessKey: 'ප්‍රවේශ  යතුර',
	advanced: 'දීය',
	advisoryContentType: 'උපදේශාත්මක අන්තර්ගත ආකාරය',
	advisoryTitle: 'උපදේශාත්මක නාමය',
	anchor: {
		toolbar: 'ආධාරය',
		menu: 'ආධාරය වෙනස් කිරීම',
		title: 'ආධාරක ',
		name: 'ආධාරකයේ නාමය',
		errorName: 'කරුණාකර ආධාරකයේ නාමය ඇතුල් කරන්න',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'ආධාරකය ඉවත් කිරීම'
	},
	anchorId: 'By Element Id', // MISSING
	anchorName: 'By Anchor Name', // MISSING
	charset: 'Linked Resource Charset', // MISSING
	cssClasses: 'විලාසපත්‍ර පන්තිය',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'E-Mail Address', // MISSING
	emailBody: 'Message Body', // MISSING
	emailSubject: 'Message Subject', // MISSING
	id: 'අංකය',
	info: 'Link Info', // MISSING
	langCode: 'භාෂා කේතය',
	langDir: 'භාෂා දිශාව',
	langDirLTR: 'වමේසිට දකුණුට',
	langDirRTL: 'දකුණේ සිට වමට',
	menu: 'Edit Link', // MISSING
	name: 'නම',
	noAnchors: '(No anchors available in the document)', // MISSING
	noEmail: 'Please type the e-mail address', // MISSING
	noUrl: 'Please type the link URL', // MISSING
	noTel: 'Please type the phone number', // MISSING
	other: '<other>', // MISSING
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Dependent (Netscape)', // MISSING
	popupFeatures: 'Popup Window Features', // MISSING
	popupFullScreen: 'Full Screen (IE)', // MISSING
	popupLeft: 'Left Position', // MISSING
	popupLocationBar: 'Location Bar', // MISSING
	popupMenuBar: 'Menu Bar', // MISSING
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'Scroll Bars', // MISSING
	popupStatusBar: 'Status Bar', // MISSING
	popupToolbar: 'Toolbar', // MISSING
	popupTop: 'Top Position', // MISSING
	rel: 'Relationship', // MISSING
	selectAnchor: 'Select an Anchor', // MISSING
	styles: 'විලාසය',
	tabIndex: 'Tab Index', // MISSING
	target: 'අරමුණ',
	targetFrame: '<frame>', // MISSING
	targetFrameName: 'Target Frame Name', // MISSING
	targetPopup: '<popup window>', // MISSING
	targetPopupName: 'Popup Window Name', // MISSING
	title: 'සබැඳිය',
	toAnchor: 'Link to anchor in the text', // MISSING
	toEmail: 'E-mail', // MISSING
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'සබැඳිය',
	type: 'Link Type', // MISSING
	unlink: 'Unlink', // MISSING
	upload: 'උඩුගතකිරීම'
} );
